@@ -20,7 +20,7 @@ from .pfeiffer import PVMassSpecReader
 from .cinfdata import CinfdataTXTReader
 
 # ec-ms
-from .zilien import ZilienTSVReader
+from .zilien import ZilienTSVReader, ZilienTMPReader
 from .ec_ms_pkl import EC_MS_CONVERTER
 
 READER_CLASSES = {
@@ -31,5 +31,6 @@ READER_CLASSES = {
     "pfeiffer": PVMassSpecReader,
     "cinfdata": CinfdataTXTReader,
     "zilien": ZilienTSVReader,
+    "zilien_tmp": ZilienTMPReader,
     "EC_MS": EC_MS_CONVERTER,
 }
